@@ -319,7 +319,10 @@ class ServiceRunTestCase(unittest.TestCase):
     @mock.patch('tutumcli.commands.tutum.Service.save')
     @mock.patch('tutumcli.commands.tutum.Service.create')
     def test_service_run(self, mock_create, mock_save, mock_start):
-        container_ports = ['80:80/tcp', '22:22']
+        exposed_ports = [80, 22]
+        published_ports = ['80:80/tcp', '22:22']
+        ports = utils.parse_published_ports(published_ports)
+        ports.extend(utils.parse_exposed_ports(exposed_ports))
         container_envvars = ['MYSQL_ADMIN=admin', 'MYSQL_PASS=password']
         linked_to_service = ['mysql:mysql', 'redis:redis']
 
@@ -327,14 +330,14 @@ class ServiceRunTestCase(unittest.TestCase):
         service.uuid = '7A4CFE51-03BB-42D6-825E-3B533888D8CD'
         mock_create.return_value = service
         mock_start.return_value = True
-        service_run('imagename', 'containername', 1, '256M', '1024M', 3, '-d', '/bin/mysql',
-                    container_ports, container_envvars, linked_to_service,
+        service_run('imagename', 'containername', 1, '256M', True, 3, '-d', '/bin/mysql',
+                    exposed_ports, published_ports, container_envvars, linked_to_service,
                     'OFF', 'OFF', 'OFF', 'poweruser', True)
 
         mock_create.assert_called_with(image='imagename', name='containername', cpu_shares=1,
-                                       memory='256M', memory_swap='1024M',
+                                       memory='256M',  privileged=True,
                                        target_num_containers=3, run_command='-d',
-                                       entrypoint='/bin/mysql', container_ports=utils.parse_ports(container_ports),
+                                       entrypoint='/bin/mysql', container_ports=ports,
                                        container_envvars=utils.parse_envvars(container_envvars),
                                        linked_to_service=utils.parse_links(linked_to_service, 'to_service'),
                                        autorestart='OFF', autoreplace='OFF', autodestroy='OFF',
@@ -346,11 +349,12 @@ class ServiceRunTestCase(unittest.TestCase):
     @mock.patch('tutumcli.commands.sys.exit')
     @mock.patch('tutumcli.commands.tutum.Service.create', side_effect=TutumApiError)
     def test_service_run_with_exception(self, mock_create, mock_exit):
-        container_ports = ['80:80/tcp', '22:22']
+        exposed_ports = ['80', '22']
+        published_ports = ['80:80/tcp', '22:22']
         container_envvars = ['MYSQL_ADMIN=admin', 'MYSQL_PASS=password']
         linked_to_service = ['mysql:mysql', 'redis:redis']
-        service_run('imagename', 'containername', 1, '256M', '1024M', 3, '-d', '/bin/mysql',
-                    container_ports, container_envvars, linked_to_service,
+        service_run('imagename', 'containername', 1, '256M', True, 3, '-d', '/bin/mysql',
+                    exposed_ports, published_ports, container_envvars, linked_to_service,
                     'OFF', 'OFF', 'OFF', 'poweruser', True)
 
         mock_exit.assert_called_with(EXCEPTION_EXIT_CODE)
@@ -1464,4 +1468,4 @@ class NodeClusterCreateTestCase(unittest.TestCase):
     def test_nodecluster_create_with_exception(self, mock_create, mock_exit):
         nodecluster_create(3, 'name', 'provider', 'region', 'nodetype')
 
-        mock_exit.assert_called_with(EXCEPTION_EXIT_CODE)
\ No newline at end of file
+        mock_exit.assert_called_with(EXCEPTION_EXIT_CODE)
