@@ -84,9 +84,9 @@ def dispatch_cmds(args):
             commands.service_redeploy(args.identifier, args.tag)
         elif args.subcmd == 'run':
             commands.service_run(image=args.image, name=args.name, cpu_shares=args.cpushares,
-                                 memory=args.memory, memory_swap=args.memoryswap,
+                                 memory=args.memory, privileged=args.privileged,
                                  target_num_containers=args.target_num_containers, run_command=args.run_command,
-                                 entrypoint=args.entrypoint, container_ports=args.port, container_envvars=args.env,
+                                 entrypoint=args.entrypoint, expose=args.expose, publish=args.publish, envvars=args.env,
                                  linked_to_service=args.link_service,
                                  autorestart=args.autorestart,
                                  autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role,
@@ -163,4 +163,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
